==> open-xchange-core_7.2.2.orig.tar.bz2: open-xchange-core-7.2.2/com.openexchange.server/src/com/openexchange/folderstorage/database/getfolder/SystemRootFolder.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.folderstorage.database.getfolder;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import com.openexchange.folderstorage.database.DatabaseFolder;
import com.openexchange.groupware.container.FolderObject;
import com.openexchange.groupware.i18n.FolderStrings;
import com.openexchange.i18n.tools.StringHelper;

/**
 * {@link SystemRootFolder} - Gets the system shared folder.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class SystemRootFolder {

    /**
     * Initializes a new {@link SystemRootFolder}.
     */
    private SystemRootFolder() {
        super();
    }

    /**
     * Gets the database folder representing system root folder.
     *
     * @param fo The folder object fetched from database
     * @return The database folder representing system root folder
     */
    public static DatabaseFolder getSystemRootFolder() {
        /*
         * The system root folder
         */
        final FolderObject fo =
            FolderObject.createVirtualFolderObject(
                FolderObject.SYSTEM_ROOT_FOLDER_ID,
                "root",
                FolderObject.SYSTEM_MODULE,
                true,
                FolderObject.SYSTEM_TYPE);
        final DatabaseFolder retval = new DatabaseFolder(fo);
        // Enforce getSubfolders() from storage
        final List<String> list = new ArrayList<String>(4);
        list.add(String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID));
        list.add(String.valueOf(FolderObject.SYSTEM_PUBLIC_FOLDER_ID));
        list.add(String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID));
        list.add(String.valueOf(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID));
        retval.setSubfolderIDs(list.toArray(new String[list.size()]));
        return retval;
    }

    /**
     * Gets the subfolder identifiers of database folder representing system root folder for given user.
     *
     * @return The subfolder identifiers of database folder representing system root folder for given user
     */
    public static List<String[]> getSystemRootFolderSubfolder(final Locale locale) {
        /*
         * The system root folder
         */
        final StringHelper sh = StringHelper.valueOf(locale);
        final List<String[]> list = new ArrayList<String[]>(4);
        list.add(new String[] { String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_PRIVATE_FOLDER_NAME) });
        list.add(new String[] { String.valueOf(FolderObject.SYSTEM_PUBLIC_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_PUBLIC_FOLDER_NAME) });
        list.add(new String[] { String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_SHARED_FOLDER_NAME) });
        list.add(new String[] { String.valueOf(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_INFOSTORE_FOLDER_NAME) });
        return list;
    }

    /**
     * Gets the subfolder identifiers of database folder representing system root folder for given user.
     *
     * @return The subfolder identifiers of database folder representing system root folder for given user
     */
    public static int[] getSystemRootFolderSubfolderAsInt() {
        /*
         * The system root folder
         */
        final int[] ret = new int[4];
        ret[0] = FolderObject.SYSTEM_PRIVATE_FOLDER_ID;
        ret[1] = FolderObject.SYSTEM_PUBLIC_FOLDER_ID;
        ret[2] = FolderObject.SYSTEM_SHARED_FOLDER_ID;
        ret[3] = FolderObject.SYSTEM_INFOSTORE_FOLDER_ID;
        return ret;
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.server/src/com/openexchange/folderstorage/database/getfolder/SystemRootFolder.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.folderstorage.database.getfolder;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import com.openexchange.folderstorage.database.DatabaseFolder;
import com.openexchange.groupware.container.FolderObject;
import com.openexchange.groupware.i18n.FolderStrings;
import com.openexchange.i18n.tools.StringHelper;

/**
 * {@link SystemRootFolder} - Gets the system shared folder.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public final class SystemRootFolder {

    private static final boolean preload = true;

    /**
     * Initializes a new {@link SystemRootFolder}.
     */
    private SystemRootFolder() {
        super();
    }

    /**
     * Gets the database folder representing system root folder.
     *
     * @param fo The folder object fetched from database
     * @return The database folder representing system root folder
     */
    public static DatabaseFolder getSystemRootFolder() {
        /*
         * The system root folder
         */
        final FolderObject fo = FolderObject.createVirtualFolderObject(FolderObject.SYSTEM_ROOT_FOLDER_ID, "root", FolderObject.SYSTEM_MODULE, true, FolderObject.SYSTEM_TYPE);
        final DatabaseFolder retval = new DatabaseFolder(fo);
        // Enforce getSubfolders() from storage
        if (preload) {
            final List<String> list = new ArrayList<String>(4);
            list.add(String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID));
            list.add(String.valueOf(FolderObject.SYSTEM_PUBLIC_FOLDER_ID));
            list.add(String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID));
            list.add(String.valueOf(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID));
            retval.setSubfolderIDs(list.toArray(new String[list.size()]));
        } else {
            retval.setSubfolderIDs(null);
            retval.setSubscribedSubfolders(true);
        }
        return retval;
    }

    private static final ConcurrentMap<Locale, List<String[]>> CACHED_SUBFOLDERS = new ConcurrentHashMap<Locale, List<String[]>>(16);

    /**
     * Gets the subfolder identifiers of database folder representing system root folder for given user.
     *
     * @return The subfolder identifiers of database folder representing system root folder for given user
     */
    public static List<String[]> getSystemRootFolderSubfolder(final Locale locale) {
        /*
         * The system root folder
         */
        List<String[]> list = CACHED_SUBFOLDERS.get(locale);
        if (null == list) {
            final StringHelper sh = StringHelper.valueOf(locale);
            final List<String[]> newList = new ArrayList<String[]>(4);
            newList.add(new String[] { String.valueOf(FolderObject.SYSTEM_PRIVATE_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_PRIVATE_FOLDER_NAME) });
            newList.add(new String[] { String.valueOf(FolderObject.SYSTEM_PUBLIC_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_PUBLIC_FOLDER_NAME) });
            newList.add(new String[] { String.valueOf(FolderObject.SYSTEM_SHARED_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_SHARED_FOLDER_NAME) });
            newList.add(new String[] { String.valueOf(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID), sh.getString(FolderStrings.SYSTEM_INFOSTORE_FOLDER_NAME) });
            list = CACHED_SUBFOLDERS.putIfAbsent(locale, newList);
            if (null == list) {
                list = newList;
            }
        }
        return list;
    }

}
